# -*- coding: utf-8 -*-

from django.db import models as fields_types
from kinder.core.helpers import recursive_get_field


def format_change(model, field_name):
    """
    Возвращает строку вида : "Ребенок: Фамилия"
    @param model: verbose name модели
    @param field_name: verbose name поля модели
    @return:
    """
    return u"{0}: {1}".format(
        model, field_name)


def format_changes(model, field_list):
    """
    Возвращает строку вида : "Ребенок: Фамилия, Имя"
    @param model: verbose name модели
    @param field_name: verbose name поля модели
    @return:
    """
    return format_change(
        model, u", ".join(map(unicode, field_list)))


def convert_value(types_map, data, name_field, value):
    """
    @param types_map: функция приведения данных к нужному формату
    @param data: инстанс модели из хранилища
    @param name_field: строковое наименование поля
    @param value: значение
    @return:
    """
    field_instance = recursive_get_field(data, name_field.replace('.', '__'))
    field_type = type(field_instance)

    type_converter = types_map.get(
        field_type, lambda v, c, f: v)

    if field_type in [fields_types.DateField,
                      fields_types.DateTimeField] and not value:
        return None

    return type_converter(value, field_type, field_instance)
